<?php
/*
|--------------------------------------------------------------------------
| escapework/manager routes
|--------------------------------------------------------------------------
*/

Route::group(['prefix' => config('manager.url')], function()
{
    # ==================================================================
    # without authentication
    # ==================================================================
    Route::group(['prefix' => 'auth', 'middleware' => 'manager.guest'], function()
    {
        Route::get('login', [
            'as'   => 'manager.auth.index',
            'uses' => config('manager.controllers.auth.index'),
        ]);

        Route::post('login', [
            'as'   => 'manager.auth.login',
            'uses' => config('manager.controllers.auth.login'),
        ]);
        Route::post('password/send', [
            'as' => 'manager.auth.password.send',
            'uses' => config('manager.controllers.auth.password.send')
        ]);
        Route::get('password/reset/{token}', [
            'as' => 'manager.password.reset.index',
            'uses' => config('manager.controllers.auth.password.index')
        ]);
        Route::post('password/reset', [
            'as' => 'manager.password.reset.update',
            'uses' => config('manager.controllers.auth.password.reset')
        ]);
    });

    # ==================================================================
    # with authentication
    # ==================================================================
    Route::group(['middleware' => 'manager.authenticated'], function()
    {
        # home
        Route::get('/', [
            'as'   => 'manager.home',
            'uses' => config('manager.controllers.home.index')
        ]);

        # logout
        Route::get('logout', [
            'as'   => 'manager.auth.logout',
            'uses' => config('manager.controllers.auth.logout'),
        ]);

        # users
        Route::get('users', ['as' => 'manager.admin-users.index', 'uses' => config('manager.controllers.UsersController') . '@index']);
        Route::get('users/inserir', ['as' => 'manager.admin-users.create', 'uses' => config('manager.controllers.UsersController') . '@create']);
        Route::post('users', ['as' => 'manager.admin-users.store', 'uses' => config('manager.controllers.UsersController') . '@store']);
        Route::get('users/{id}', ['as' => 'manager.admin-users.show', 'uses' => config('manager.controllers.UsersController') . '@show']);
        Route::get('users/{id}/editar', ['as' => 'manager.admin-users.edit', 'uses' => config('manager.controllers.UsersController') . '@edit']);
        Route::put('users/{id}', ['as' => 'manager.admin-users.update', 'uses' => config('manager.controllers.UsersController') . '@update']);
        Route::delete('users/{id}', ['as' => 'manager.admin-users.destroy', 'uses' => config('manager.controllers.UsersController') . '@destroy']);

        # update password
        Route::get('password/update', [
            'as'   => 'manager.users.passwod.index',
            'uses' => config('manager.controllers.users.password.index'),
        ]);

        Route::put('password/update', [
            'as'   => 'manager.users.passwod.update',
            'uses' => config('manager.controllers.users.password.update'),
        ]);

        # roles
        Route::resource('roles', config('manager.controllers.RolesController'));

        # logs
        Route::get('logs', ['as' => 'manager.logs.index', 'uses' => 'Rap2hpoutre\LaravelLogViewer\LogViewerController@index']);

        # rotinas
        Route::get('rotinas', ['as' => 'manager.routines.index', 'uses' => 'EscapeWork\Manager\Http\Controllers\RoutinesController@index']);
        Route::post('rotinas/executar', ['as' => 'manager.routines.execute', 'uses' => 'EscapeWork\Manager\Http\Controllers\RoutinesController@execute']);
    });
});
